import React from 'react'
import PropTypes from 'prop-types'
import { Link } from 'gatsby'
import debounce from 'lodash'

const BottomBanner = ({ title, url, buttonText, text, imageUrl }) => {
    function closeBanner(e) {
        e.preventDefault()
        if (typeof window !== "undefined") {
            var banners = document.getElementsByClassName('bottom-banner')
            for (var i=0;i<banners.length;i++) {
                banners[i].classList.add('hidden')
                banners[i].classList.add('closed')
            }
        }
    }
    
    function showBanner() {
        // TODO: debounce this?
        if (typeof window !== "undefined") {
            var winScroll = document.body.scrollTop || document.documentElement.scrollTop;
            var height = document.documentElement.scrollHeight - document.documentElement.clientHeight;
            var scrolled = (winScroll / height) * 100;
            if (scrolled > 60) {
                // Show banner
                var banners = document.getElementsByClassName('bottom-banner')
                for (var i=0;i<banners.length;i++) {
                    // Show only if not already closed
                    if (!banners[i].classList.contains('closed')) {
                        banners[i].classList.remove('hidden')
                    }
                }
                // Remove listener
                window.removeEventListener('scroll', showBanner)
            }
        }
    }

    if (typeof window !== "undefined") {
        window.addEventListener('scroll', showBanner);

        // remove this event listener when we open a new page (a new
        // event listener will be created when required)
        window.addEventListener('hashchange', () => {
            window.removeEventListener('scroll', showBanner)
        })
    }

    return(
        <a className="bottom-banner hidden" href={url} target="_blank">
            {imageUrl && <div className="banner-image"><img src={imageUrl} height="auto" width="auto" /></div>}
            <div className="banner-content">
                {title && <h2>{title}</h2>}
                {text && <p>{ text }</p>}
            </div>
                <button className="close-button" onClick={closeBanner}>X</button>
        </a>
    )
}

BottomBanner.propTypes = {
    title: PropTypes.string.isRequired,
    url: PropTypes.string.isRequired,
    text: PropTypes.string,
    imageUrl: PropTypes.string,
}

export default BottomBanner
