import React from 'react'
import PropTypes from 'prop-types'
import { graphql } from 'gatsby'
import { Link } from 'gatsby'
import Helmet from 'react-helmet'

import { Layout, BottomBanner } from '../components/common'
import { MetaData } from '../components/common/meta'
import config from '../utils/siteConfig'

/**
* Single post view (/:slug)
*
* This file renders a single post and loads all the content.
*
*/
const Post = ({ data, location }) => {
    const post = data.ghostPost

    return (
            <>
                <MetaData
                    data={data}
                    location={location}
                    type="article"
                />
                <Helmet>
                    <style type="text/css">{`${post.codeinjection_styles}`}</style>
                </Helmet>
                <Layout hasFeatureImage={ post.feature_image }>
                { post.feature_image ?
                    <figure className="post-feature-image">
                        <img src={ post.feature_image.replace(new RegExp(config.mediaUrlFrom, 'g'), config.mediaUrlTo) } alt={ post.title } />
                    </figure> : null }
                    <div className="container">
                        <article className="content">
                            <section className="post-full-content">
                                <h1 className="content-title">{post.title}</h1>

                                {/* The main post content */ }
                                <section
                                    className="content-body load-external-scripts"
                                    dangerouslySetInnerHTML={{ __html: post.html ? post.html.replace(new RegExp(config.mediaUrlFrom, 'g'), config.mediaUrlTo) : post.html }}
                                />
                                <section className="content-footer">
                                    <p>
                                        Written by { post.authors.map((author, key) => ([
                                        <Link to={`/author/${author.slug}`}>{ author.name }</Link>,
                                            <span>{ key == post.authors.length-1 ? '' :
                                                key == post.authors.length-2 ? ' and ' : ', ' }</span>
                                    ]))}
                                    </p>
                                </section>
                            </section>
                        </article>
                    </div>
                </Layout>
                <BottomBanner title="Snipette in print?"
                    text="We're planning to bring out a print edition of Snipette—but need your suggestions. Help us by taking the survey!"
                    url="https://forms.gle/H4FpwJzMqehHceXx8"
                    imageUrl="https://media.snipettemag.com/manual-uploads/survey-welcome-banner.png"
                />
            </>
    )
}

Post.propTypes = {
    data: PropTypes.shape({
        ghostPost: PropTypes.shape({
            codeinjection_styles: PropTypes.object,
            title: PropTypes.string.isRequired,
            html: PropTypes.string.isRequired,
            feature_image: PropTypes.string,
        }).isRequired,
    }).isRequired,
    location: PropTypes.object.isRequired,
}

export default Post

export const postQuery = graphql`
    query($slug: String!) {
        ghostPost(slug: { eq: $slug }) {
            ...GhostPostFields
        }
    }
`
